[PATCH 75/94] mm/huge_memory: Use vma_next() instead of vma linked list

Liam Howlett liam.howlett at oracle.com
Wed Apr 28 16:36:24 BST 2021


Signed-off-by: Liam R. Howlett <Liam.Howlett at Oracle.com>
---
 mm/huge_memory.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/mm/huge_memory.c b/mm/huge_memory.c
index 63ed6b25deaa..cf05049afb1b 100644
--- a/mm/huge_memory.c
+++ b/mm/huge_memory.c
@@ -2325,11 +2325,11 @@ void vma_adjust_trans_huge(struct vm_area_struct *vma,
 	split_huge_pmd_if_needed(vma, end);
 
 	/*
 	 * If we're also updating the vma->vm_next->vm_start,
 	 * check if we need to split it.
 	 */
 	if (adjust_next > 0) {
-		struct vm_area_struct *next = vma->vm_next;
+		struct vm_area_struct *next = vma_next(vma->vm_mm, vma);
 		unsigned long nstart = next->vm_start;
 		nstart += adjust_next;
 		split_huge_pmd_if_needed(next, nstart);
@@ -2325,11 +2325,11 @@ void vma_adjust_trans_huge(struct vm_area_struct *vma,
 
 	/*
-	 * If we're also updating the vma->vm_next->vm_start,
+	 * If we're also updating the vma_next(vma)->vm_start,
 	 * check if we need to split it.
 	 */
-- 
2.30.2



More information about the maple-tree mailing list